pub struct CreateInboundShipmentPlanRequest {
    pub ship_from_address: Box<Address>,
    pub label_prep_preference: LabelPrepPreference,
    pub ship_to_country_code: Option<String>,
    pub ship_to_country_subdivision_code: Option<String>,
    pub inbound_shipment_plan_request_items: Vec<InboundShipmentPlanRequestItem>,
}
CreateInboundShipmentPlanRequest : The request schema for the createInboundShipmentPlan operation.

Fields

ship_from_address: Box<Address>label_prep_preference: LabelPrepPreferenceship_to_country_code: Option<String>

The two-character country code for the country where the inbound shipment is to be sent. Note: Not required. Specifying both ShipToCountryCode and ShipToCountrySubdivisionCode returns an error. Values: ShipToCountryCode values for North America: * CA – Canada * MX - Mexico * US - United States ShipToCountryCode values for MCI sellers in Europe: * DE – Germany * ES – Spain * FR – France * GB – United Kingdom * IT – Italy Default: The country code for the seller’s home marketplace.

ship_to_country_subdivision_code: Option<String>

The two-character country code, followed by a dash and then up to three characters that represent the subdivision of the country where the inbound shipment is to be sent. For example, "IN-MH". In full ISO 3166-2 format. Note: Not required. Specifying both ShipToCountryCode and ShipToCountrySubdivisionCode returns an error.

inbound_shipment_plan_request_items: Vec<InboundShipmentPlanRequestItem>

Implementations

The request schema for the createInboundShipmentPlan operation.